#
# spec file for package flac
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover      12
%define sover_plus 10

Name:           flac
Version:        1.4.3
Release:        1.4
Summary:        Free Lossless Audio Codec
License:        BSD-3-Clause AND GPL-2.0-or-later AND GFDL-1.2-only
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://xiph.org/flac/
#Git-Web:       https://github.com/xiph/flac
#Git-Clone:     https://github.com/xiph/flac.git
#Changelog:     https://xiph.org/flac/changelog.html
Source:         https://github.com/xiph/flac/releases/download/%{version}/%{name}-%{version}.tar.xz
Source2:        baselibs.conf

BuildRequires:  autoconf >= 2.60
BuildRequires:  automake >= 1.11
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(ogg)
Obsoletes:      %{name}-doc
%{?suse_build_hwcaps_libs}

%description
FLAC is an audio coding format for lossless compression of digital
audio, and is also the name of the reference software package that
includes a codec implementation. Digital audio compressed by FLAC's
algorithm can typically be reduced to between 50 and 70 percent of
its original size, and decompresses to an identical copy of the
original audio data.

%package -n libFLAC%{sover}
Summary:        Free Lossless Audio Codec Library
Group:          System/Libraries
Obsoletes:      libflac < %{version}
Provides:       libflac = %{version}

%description -n libFLAC%{sover}
FLAC is an audio coding format for lossless compression of digital
audio, and is also the name of the reference software package that
includes a codec implementation.

This package contains the C API library for FLAC.

%package -n libFLAC++%{sover_plus}
Summary:        Free Lossless Audio Codec Library
Group:          System/Libraries

%description -n libFLAC++%{sover_plus}
FLAC is an audio coding format for lossless compression of digital
audio, and is also the name of the reference software package that
includes a codec implementation.

This package contains the C++ API library for FLAC.

%package devel
Summary:        FLAC Library Development Package
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libFLAC%{sover} = %{version}
Requires:       libFLAC++%{sover_plus} = %{version}
Requires:       libstdc++-devel

%description devel
This package contains the files needed to compile programs that use
the FLAC library.

%prep
%autosetup -p1

%build
autoreconf -fvi
%configure \
	--disable-silent-rules \
	--disable-thorough-tests \
	--disable-static \
	--disable-rpath
%make_build

%install
%make_install docdir="%{_docdir}/%{name}"
find %{buildroot} -type f -name "*.la" -delete -print
# wrongy installed docs
rm -rf %{buildroot}%{_datadir}/doc/%{name}-%{version}/

%check
make check %{?_smp_mflags}

%ldconfig_scriptlets -n libFLAC%{sover}
%ldconfig_scriptlets -n libFLAC++%{sover_plus}

%files
%doc README.md
%{_bindir}/*
%{_mandir}/man*/*

%files -n libFLAC%{sover}
%license COPYING*
%{_libdir}/libFLAC.so.%{sover}*

%files -n libFLAC++%{sover_plus}
%license COPYING*
%{_libdir}/libFLAC++.so.%{sover_plus}*

%files devel
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*.m4
%{_docdir}/%{name}/
%exclude %{_docdir}/%{name}/README.md

%changelog
* Fri Jun 23 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.4.3:
  + General
  * All PowerPC-specific code has been removed, as it turned out
    those improvements didn't actually improve anything
  * Large improvements in encoder speed for all presets. The
    largest change is for the fastest presets and for 24-bit and
    32-bit inputs.
  * Small improvement in decoder speed for BMI2-capable CPUs
  * Various documentation fixes and cleanups
  * Various fixes
  * Fix building on Universal Windows Platform
  + flac
  * A lot of small fixes for bugs found by fuzzing
  * Various improvements to the --keep-foreign-metadata and
  - -keep-foreign-metadata-if-present options on decoding
    + The output format (WAV/AIFF/RF64 etc.) is now automatically
    selected based on what kind of foreign metadata is stored
    + Decoded file is checked afterwards, to see whether stored
    foreign format data agrees with FLAC audio properties
    + AIFF-C sowt data can now be restored
  * Add --force-legacy-wave-format option, to decode to WAV with
    WAVEFORMATPCM where WAVE_FORMAT_EXTENSIBLE would be more
    appropriate
  * Add --force-aiff-c-none-format and --force-aiff-c-sowt-format
    to decode to AIFF-C
  * The storage of WAVEFORMATEXTENSIBLE_CHANNEL_MASK is no longer
    restricted to known channel orderings
  * Throw an error when WAV or AIFF files are over 4GiB in length
    and the --ignore-chunk-sizes option is not set
  * Warn on testing files when ID3v2 tags are found
  * Warn when data trails the audio data of a WAV/AIFF/RF64/W64
    file
  * Fix output file not being deleted after error on Windows
  * Removal of the --sector--align option
  + metaflac
  * A lot of small fixes for bugs found by fuzzing
  * Added options --append and --data-format, which makes it
    possible to copy metadata blocks from one FLAC file to another
  * Added option --remove-all-tags-except
  * Added option --show-all-tags
  + libFLAC
  * No longer write seektables to Ogg, even when specifically
    asked for. Seektables in Ogg are not defined
  * Add functions FLAC__metadata_object_set_raw and
    FLAC__metadata_object_get_raw to convert between blob and
    FLAC__StreamMetadata
  + Build system
  * Autoconf (configure): The option --enable-64-bit-words is now
    on by default
  * CMake: The option ENABLE_64_BIT_WORDS is now on by default
  + Testing/validation
  * Fuzzers were added for the flac and metaflac command line
    tools
  * Fuzzer coverage was improved
- Changed source to github link since it wasn't released in the
  xiph page.
* Sat Mar 11 2023 Martin Pluskal <mpluskal@suse.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
* Fri Nov 25 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.4.2:
  + General
  * Remove xmms plugin (Martijn van Beurden, TokyoBlackHole)
  * Remove all pure assembler, removing build dependency on nasm
  * Made console output more uniform across different platforms
    and CPUs
  * Improve ability to tune compile for a certain system (for
    example with -march=native) when combining with
  - -disable-asm-optimizations: plain C functions can now be
    better optimized
  + Build system
  * Default CFLAGS are now prepended instead of dropped when user
    CFLAGS are set
  * -msse2 is no longer added by default (was only applicable
    to x86)
  * Fix cross-compiling and out-of-tree building when pandoc and
    doxygen are not available
  * Fix issue with Clang not compiling functions with intrinsics
  * Fix detection of bswap intrinsics (Ozkan Sezer)
  * Improve search for libssp on MinGW (Ozkan Sezer,
    Martijn van Beurden)
  + libFLAC
  * Fix issue when the libFLAC user seeks in a file instead of
    libFLAC itself
- Drop obsoleted flac-cflags.patch
* Fri Sep 23 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.4.1:
  * CMake fixes
  * Add checks that man pages and api docs end up in tarball
  * Enable installation of prebuilt man pages and api docs
  * Fix compiler warnings
  * Fix format specifier
  * Fix versioning from git
- Rebase flac-cflags.patch
* Sun Sep 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.0:
  + General:
  * It is now possible to limit the minimum bitrate of a FLAC
    file generated by libFLAC and with the flac tool to 1
    bit/sample. This function can be used to aid live streaming,
    for example for internet radio
  * Encoding files with sample rates up to 1'048'575Hz is now
    possible.
  * Compression of preset -3 through -8 was slightly improved at
    the cost of a small decrease in encoding speed by increasing
    the precision with which autocorrelation was calculated
  * Encoding speed of preset -0, -1 and -2 was slightly improved
  * Compression of presets -1 and -4 was slighly improved on
    certain material by changing the adaptive mid-side heuristics
  * Speedups specifically targeting 64-bit ARMv8 devices using
    NEON were integrated
  * Speedups for x86_64 CPUs having the FMA instruction set
    extention are added
  * Encoding and decoding of 32-bit PCM is now possible
  + (Ogg) FLAC format:
  * The FLAC format document is being rewritten by the IETF
    CELLAR working group. The latest draft can be found on
    https://datatracker.ietf.org/doc/draft-ietf-cellar-flac/
  * The FLAC format document specifies no bounds for the
    residual. In other to match current decoder implementations,
    it is proposed to bound the residual to the range provided by
    a 32-bit int signed two's complement. This limit must be
    checked by FLAC encoders as to keep FLAC decoders free from
    the complexity of being to decode a residual exceeding a
    32-bit int.
  * There is now a set of files available to test whether a FLAC
    decoder implements the format correctly. This FLAC decoder
    testbench can be found at
    https://github.com/ietf-wg-cellar/flac-test-files. Also,
    results of testing hard- and software can be found here at
    https://wiki.hydrogenaud.io/index.php?title=FLAC_decoder_testbench.
  + flac:
  * The option --limit-min-bitrate was added to aid streaming,
    see github #264
  * The option --keep-foreign-metadata-if-present is added. This
    option works the same as --keep-foreign-metadata, but does
    return a warning instead of an error if no foreign metadata
    was found to store or restore
  * The warning returned by the foreign metadata handling is now
    clearer in case a user tries to restore foreign metadata of
    the wrong type, for example decoding a FLAC file containing
    AIFF foreign metadata to a WAV file
  * A problem when using the analyse function causing the first
    frame to have a wrong size and offset was fixed
  * Fix bug where channel mask of a file is unintentionally
    reused when several files are processed with one command
  * The order of compression-related commands is no longer
    important, i.e. -8ep gives the same result as -ep8.
    Previously, a compression level (like -8) would override a
    more specific setting (like -e or -p). This is no longer the
    case
  * flac now checks the block-align property of WAV files to
    ensure non-standard WAV files (for which flac has no
    handling) are not mangled
  + build system:
  * MSVC and Makefile.lite build system files have been removed.
    Building with MSVC (Visual Studio) can be done by using CMake
  * Various CMake improvements, especially for creating MSVC
    build files
  * Various fixes for MinGW
  * Removed obsolete autotools macro's to silence warnings
  * Fixes for FreeBSD PowerPC
  * Fixed some compiler warnings
  * Fix building with uclibc
  + testing/validation:
  * Addition of new encoder fuzzer, adding fuzzing for 8, 24 and
    32-bit inputs
  * Addition of new decoder fuzzer, adding coverage of seeking
    code
  * Addition of metadata fuzzer, adding coverage of metadata APIs
  * Various improvements to fuzzers to improve code coverage,
    fuzzing speed and stability
  * Many changes to test suite to improve cross-platform
    compatibility
  * Windows CI now also builds the whole test suite
  * Clang-format file added
  * Add warning on using v141_xp platform toolset with /MT
  + libraries:
  * Various seeking fixes
  * Various bugs fixed found by fuzzing
  * On decoding, it is now checked whether residuals can be
    contained by a 32-bit int, preventing integer overflow
  * Add check that samples supplied to libFLAC actually fall
    within the bps set
  * Add checks when parsing metadata blocks to not allocate
    excessive amounts of memory and not overread
  * Undocumented Windows-only utf8 functions are no longer
    exported to the DLL interface
  * Removed all assembler and intrinsics code from the decoder to
    improve fuzzing, as they provided only a small speed benefit
  * The bitwriter buffer is limited in size to 2^24 bytes, so it
    cannot write excessively large files. This is a backup in
    case another bug in this area creeps (back) in.
  * The metadata iterations should now never return a
    vorbiscomment entry with NULL as an entry, now always at
    least an empty string is returned
  + documentation: Removed html documentation and generate man
    pages from markdown
  + Interface changes:
  * libFLAC:
    . Addition of FLAC__stream_encoder_set_limit_min_bitrate()
    and FLAC__stream_encoder_get_limit_min_bitrate(), see
    github #264
    . get_client_data_from_decoder is renamed
    FLAC__get_decoder_client_data(), see github #124
    . All API functions taking a filename as an argument now take
    UTF-8 filenames on Windows, and no longer accept filenames
    using the current codepage
    . FLAC__Frame struct has changed: warmup samples are now
    stored in FLAC__int64 instead of FLAC__int32 types, and
    verbatim samples can now be stored in either FLAC__int32 or
    FLAC__int64 depending on whether samples fix the former or
    latter
    . The FLAC__StreamMetadata struct now has a tag, so it can be
    forward declared
  * libFLAC++:
    . Addition of ::set_limit_min_bitrate() and
    ::get_limit_min_bitrate(), see github #264
    . All API functions taking a filename as an argument now take
    UTF-8 filenames on Windows, and no longer accept filenames
    using the current codepage
    . The ::FLAC__Frame struct has changed, see the libFLAC
    interface change.
- Rebase flac-cflags.patch with quilt.
- Drop patch fixed differently upstream, see github #329
  + 0001-Revert-libFLAC-stream_decoder.c-Use-current-position.patch
- Bump sonames following upstream changes (also in baselibs.conf).
- Add sover and sover_plus defines, ease future soname bumps.
- Use ldconfig_scriptlets macro for post(un) handling.
- Use make_build macro.
- Update Git-Web and Git-Clone urls to new home on github.
- Replace gcc-c++ BuildRequires with generic c++_compiler and
  c_compiler BuildRequires: Package needs a c and c++ compiler, not
  explicitly gcc-c++.
* Tue Mar  1 2022 tiwai@suse.de
- Fix the regression for audiofile, reverting the problematic change
  0001-Revert-libFLAC-stream_decoder.c-Use-current-position.patch
* Tue Feb 22 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to release 1.3.4:
  + General:
  * Fix 12 decoder bugs found by oss-fuzz, including CVE-2020-0499
  * Fix encoder bug CVE-2021-0561
  * Integrate oss-fuzzers
  * Seeking fixes
  * Various fixes and improvements
  + flac:
  * Various fixes and improvements
* Sun Sep  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.3
  * Improve SIMD decoding of 24 bit files
- Drop flac-CVE-2017-6888.patch (merged upstream)
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Remove useless --with-pic (only useful for --enable-static).
- Trim authorship and licensing info from description,
  this is metadata.
* Fri Jan 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop doxygen dependency to reduce python3 buildcycle
* Fri Apr 27 2018 tiwai@suse.de
- Fix memory leak in read_metadata_vorbiscomment_() function
  (CVE-2017-6888, bsc#1091045):
  flac-CVE-2017-6888.patch
* Sun Jan  1 2017 aloisio@gmx.com
- Update to version 1.3.2
  * Fix undefined behaviour using GCC/Clang UBSAN (erikd).
  * General hardening via fuzz testing with AFL (erikd and
    others).
  * General code improvements (lvqcl, erikd and others).
  * Add FLAC in MP4 specification docs (Ralph Giles).
  * Fix some cppcheck warnings (erikd).
  * Assume all currently used OSes support SSE2.
  flac:
  * Fix potential infinite loop on flac-to-flac conversion
    (erikd).
  * Add WAVEFORMATEXTENSIBLE to WAV (as needed) when
    decoding (lvqcl).
  * Only write vorbis-comments if they are non-empty.
  * Error out if decoding RAW with bits != (8|16|24).
  metaflac:
  * Add --scan-replay-gain option.
  libraries:
  * CPU detection cleanup and fixes (Julian Calaby, erikd
    and lvqcl).
  * Fix two stream decoder bugs (Max Kellermann).
  * Fix a NULL dereference bug (on a malformed file).
  * Changed the LPC order guess for a slight compression
    improvement, particularly for classical music
    (Martijn van Beurden).
  * Improved encoding speed on older Intel CPUs.
  * Fixed a seeking bug when decoding certain files
    (Miroslav Lichvar).
  * Put an upper bound (32768) on the number of seek
    points.
  * Fix potential memory leaks.
  * Support 64bit brword/bwword allowing
    FLAC__BYTES_PER_WORD to be set to 8 (disabled by
    default).
  * Fix an out-of-bounds heap read.
- Refreshed flac-cflags.patch
* Sat Sep 10 2016 tchvatal@suse.com
- Drop patch that should be upstreamed first, otherwise we will
  have to keep it ofrever:
  * flac-ocloexec.patch
- Drop wrong patch:
  * flac-fix-pkgconfig.patch
    + If using this change you get assert.h include overriden in your
    project by the one from FLAC/ which is not what upstream desired
    If packages fail to build they should fix their include
* Sat Mar 21 2015 mpluskal@suse.com
- Build documentation as noarch
* Fri Mar 20 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update url
- Remove no longer needed patches
  * flac-fix-CVE-2014-8962.patch
  * flac-fix-CVE-2014-9028.patch
  * 0001-getopt_long-not-broken-here.patch
- Remove following as benefit of using openssl is small
  * 0001-Allow-use-of-openSSL.patch
- Add flac-cflags.patch
- Use doxygen to build documentation
- Split documentation to separate package
- Update to 1.3.1
  * Improved decoding efficiency of all bit depths but especially
    so for 24 bits for IA32 architecture (lvqcl and Miroslav Lichvar).
  * Faster encoding using SSE and AVX (lvqcl).
  * Fixed bartlett, bartlett_hann and triangle functions.
  * New apodization functions partial_tukey and punchout_tukey for
    improved compression (Martijn van Beurden).
  * Retuned compression presets to incorporate new apodization
    functions (Martijn van Beurden).
  * Fix -Wcast-align warnings on armhf architecture (Erik de
    Castro Lopo).
  * Help output documentation improvements.
  * I/O buffering improvements on Windows to reduce disk
    fragmentation when writing files.
  * Only write vorbis-comments if they are non-empty.
  * Fix symbol visibility in XMMS plugin.
  * Many fixes and improvements across all the build systems.
  * Fix CVE-2014-9028 (heap write overflow) and CVE-2014-8962
    (heap read overflow)
* Wed Nov 26 2014 tiwai@suse.de
- A couple of security fixes:
  * flac-fix-CVE-2014-8962.patch:
    arbitrary code execution by a stack overflow (CVE-2014-8962,
    bnc#906831)
  * flac-fix-CVE-2014-9028.patch:
    Heap overflow via specially crafted .flac files (CVE-2014-9028,
    bnc#907016)
* Mon Jul  1 2013 jengelh@inai.de
- Update to final upstream release 1.3.0
  * No user-visible changes
- More robust make install call
* Sun May 26 2013 crrodriguez@opensuse.org
- Update to flac 1.3.0pre4 (packaged as 1.2.99_git* to avoid
  messing with RPM versioning)
  * Mostly non-linux related bugfixes plus autotools fixes
  - flac-openssl.patch --> 0001-Allow-use-of-openSSL.patch
  - remove flac-1.2.1-automake1_13.patch, fixed in upstream.
  - add 0001-getopt_long-not-broken-here.patch, FLAC bundles
  GNU-compatible getopt_long for broken OS, but we do have
  a functional version in libc already.
* Mon Apr 22 2013 cfarrell@suse.com
- license update: BSD-3-Clause and GPL-2.0+ and GFDL-1.2
  Numerous GPL-2.0+ licensed files;documtation is GFDL-1.2
* Thu Feb 28 2013 seife+obs@b1-systems.com
- add flac-1.2.1-automake1_13.patch, fix build with automake-1.13.1
* Tue Dec 18 2012 idonmez@suse.com
- Add flac-fix-pkgconfig.patch to fix includedir in the pkgconfig
  files.
* Sat Dec  8 2012 crrodriguez@opensuse.org
- add xz buildrequires for old distros.
* Sat Dec  8 2012 crrodriguez@opensuse.org
- Update to current git
  * patches deleted:
  - flac-1.2.1-asm.patch
  - flac-1.2.1-bitreader.patch
  - flac-gcc43-fixes.diff
  - flac-gcc47.patch
  - flac-leaks.patch
  - flac-no-xmms.diff
  - flac-visibility.patch
  - flac-printf-format-fix.diff
  All Upstreamed either by us or other distros.
- Add flac-openssl.patch, do crypto with openssl (not wanted upstream)
- Restore make check
* Tue Sep  4 2012 schwab@linux-m68k.org
- Don't ignore $(AM_CFLAGS).
- Remove ppc patch.
* Tue Mar 13 2012 dimstar@opensuse.org
- Add flac-gcc47.patch: Replacing strcpy without 'lenght
  limitation' with strncpy, limited to 4 chars. This is safe, as we
  check the length already to be sure it is 4 chars, yet do not
  suffer from the problem that strcpy wants to add a '\0' char in
  plus to the target string.
* Thu Mar  8 2012 dvaleev@suse.com
- don't use fvisibility=hidden on ppc. As it can't find symbols
  afterwards
* Fri Jan 27 2012 crrodriguez@opensuse.org
- Fix some memory and resources leak.
- Link shared libraries with -Bsymbolic-functions
- annotate relevant functions with proper attributes to
  allow the compiler generate better code (attribute hot. alloc_size)
* Tue Jan 24 2012 crrodriguez@opensuse.org
- Support symbol visibility features
- Disable test suite, nothing wrong with it, it just
  takes too long to run and uses private/hidden symbols to
  test flac's internals.
* Sun Nov 20 2011 crrodriguez@opensuse.org
- Use O_CLOEXEC in all library code.
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Sep 28 2011 crrodriguez@opensuse.org
- Build with --enable-sse, this only disables runtime
  checking if the *OS* supports SSE, which registers a
  SIGILL signal handler then tries to execute SSE code...
  it still tests the running *CPU* though.
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
- Add flac-devel to baselibs
* Sat Aug  6 2011 crrodriguez@opensuse.org
- Do not build with -fno-strict-aliasing since is no longer
  required.
- Impoer two patches from redhat, one speeds up decoding and
  the other enables the working ASM optimizations.
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- run make check, but only the basic test suite, complete
  one takes hours.
* Wed Dec 16 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 13 2007 crrodriguez@suse.de
- disable static libraries
- remove uneeded dependency on libogg-devel in the -devel package
- remove "la" files
* Mon Oct 22 2007 tiwai@suse.de
- fix build with gcc 4.3.
* Fri Oct 12 2007 tiwai@suse.de
- updated to version 1.2.1:
  * VUL-0: flac integer overflows (#333278)
  * new --keep-foreign-metadata, --no-utf8-convert options
  * changed default extension for Ogg FLAC to .oga
  * many other fixes, see changelog
* Wed Jul 25 2007 tiwai@suse.de
- updated to version 1.2.0:
  * small encoding speedups
  * runtime SSE OS support
  * fixed bug with invalid seek tables
  * added FLAC__format_sample_rate_is_subset(),
    FLAC::Decoder::Stream::get_decoder_position()
- clean up spec file
* Fri Jun  8 2007 tiwai@suse.de
- add provides and obsolets for libflac.
* Tue Jun  5 2007 tiwai@suse.de
- split to packages libFLAC8 and libFLAC++6 to follow more the
  library packaging policy.
* Tue Apr 10 2007 tiwai@suse.de
- fix post and postun for libflac.
- fix compile warnings
* Wed Apr  4 2007 tiwai@suse.de
- updated to version 1.1.4:
  * improved compression with no change to format or decrease
    in speed.
  * encoding and decoding speedups for all modes. Encoding at
  - 8 is twice as fast.
  * large format support.
  * supports FLAC and Ogg FLAC as input encoder.
  * misc bug fixes
- split library to libflac sub-package to reduce package
  dependencies.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul  7 2005 tiwai@suse.de
- fix Requires of devel subpackage.
* Wed May 25 2005 tiwai@suse.de
- updated to version 1.1.2.
* Fri Feb 25 2005 tiwai@suse.de
- split flac-xmms and flac-bmp plugins to another spec file
  to avoid too deep dependencies.
* Fri Jan 28 2005 tiwai@suse.de
- fix many compile warnings
- add BMP plugin support
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.1.1.
* Tue Aug 24 2004 tiwai@suse.de
- fixed neededforbuild for xmms.
* Mon Apr 26 2004 ro@suse.de
- add -fno-strict-aliasing
* Wed Jan 21 2004 tiwai@suse.de
- fixed quoting in m4 files.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig to %%postun
* Tue May 27 2003 ro@suse.de
- remove unpackaged files from buildroot
* Tue Apr  1 2003 ro@suse.de
- added xmms-devel to neededforbuild
* Thu Feb 13 2003 tiwai@suse.de
- fixed the installation path of xmms plugin.
- added la file for plugin.
* Mon Jan 27 2003 tiwai@suse.de
- updated to version 1.1.0.
* Wed Nov 27 2002 tiwai@suse.de
- added the compatible layer for version 1.0.3 (flac-compat.dif).
* Mon Nov 25 2002 tiwai@suse.de
- updated to version 1.0.4.
- fixed neeededforbuild: xf86 -> x-devel-packages.
- added id3lib to neededforbuild.
- regenrated prototype patches.  renamed the patch to avoid
  name confliction.
* Tue Sep 17 2002 pthomas@suse.de
- Add -lsdc++ to LIBADD in src/libFLAC++/Makefile.am to work
  around a bug in libtool 1.4.2.
- Properly use (void) not () in prototypes.
- Omit -I/usr/include from LIBFLAC_CFLAGS in libFLAC.m4 as
  it's searched by default.
- Omit -L/usr/lib from LIBFLAC_LIBS in libFLAC.m4
* Mon Jul 29 2002 tiwai@suse.de
- added %%run_ldconfig.
* Fri Jul  5 2002 tiwai@suse.de
- updated to version 1.0.3.
* Mon Jun 24 2002 tiwai@suse.de
- fixed file permission of xmms plugins.
* Tue May 21 2002 tiwai@suse.de
- added missing *.so to the filelist.
* Tue May 21 2002 tiwai@suse.de
- initial version: 1.0.2.
